# owotrans

Owotrans is a module that will convert your text to owo

### Installation
 `pip install owotranslator`

### Usage
>import owotrans

>owo('Hello there, General Kenobi')

'Hewwo thewe, Genewaw Kenobi'


License
----
MIT
